### Features

- pandas.DataFrame
- sqlalchemy orm C.R.U.D Bulk operations
- Django orm C.R.U.D Bulk operations

# pandas-orm

![](https://raw.githubusercontent.com/ilyashusterman/pandas-orm/master/source_docs/_static/logo.png)

![](https://img.shields.io/github/stars/ilyashusterman/pandas-orm) ![](	https://img.shields.io/github/forks/ilyashusterman/pandas-orm) ![](	https://img.shields.io/github/license/ilyashusterman/pandas-orm)  ![](	https://img.shields.io/github/issues/ilyashusterman/pandas-orm)![](	https://img.shields.io/badge/build-success-brightgreen)

#[Documentation](https://ilyashusterman.github.io/pandas-orm/)
----


